# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from unifieddatalibrary import Unifieddatalibrary, AsyncUnifieddatalibrary
from unifieddatalibrary.types import (
    SeradataopticalpayloadGetResponse,
    SeradataopticalpayloadListResponse,
    SeradataopticalpayloadTupleResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSeradataopticalpayload:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Unifieddatalibrary) -> None:
        seradataopticalpayload = client.seradataopticalpayload.create(
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        )
        assert seradataopticalpayload is None

    @parametrize
    def test_method_create_with_all_params(self, client: Unifieddatalibrary) -> None:
        seradataopticalpayload = client.seradataopticalpayload.create(
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
            id="SERADATAOPTICALPAYLOAD-ID",
            best_resolution=1.23,
            field_of_regard=1.23,
            field_of_view=1.23,
            ground_station_locations="groundStationLocations",
            ground_stations="groundStations",
            hosted_for_company_org_id="hostedForCompanyOrgId",
            id_sensor="idSensor",
            imaging_payload_category="Infrared",
            manufacturer_org_id="manufacturerOrgId",
            name="TOURNESOL",
            notes="Sample Notes",
            number_of_film_return_canisters=1,
            origin="THIRD_PARTY_DATASOURCE",
            pointing_method="Spacecraft",
            recorder_size="1024",
            spectral_band="Green",
            spectral_frequency_limits="0.51",
            swath_width=1.23,
        )
        assert seradataopticalpayload is None

    @parametrize
    def test_raw_response_create(self, client: Unifieddatalibrary) -> None:
        response = client.seradataopticalpayload.with_raw_response.create(
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = response.parse()
        assert seradataopticalpayload is None

    @parametrize
    def test_streaming_response_create(self, client: Unifieddatalibrary) -> None:
        with client.seradataopticalpayload.with_streaming_response.create(
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = response.parse()
            assert seradataopticalpayload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_update(self, client: Unifieddatalibrary) -> None:
        seradataopticalpayload = client.seradataopticalpayload.update(
            path_id="id",
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        )
        assert seradataopticalpayload is None

    @parametrize
    def test_method_update_with_all_params(self, client: Unifieddatalibrary) -> None:
        seradataopticalpayload = client.seradataopticalpayload.update(
            path_id="id",
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
            body_id="SERADATAOPTICALPAYLOAD-ID",
            best_resolution=1.23,
            field_of_regard=1.23,
            field_of_view=1.23,
            ground_station_locations="groundStationLocations",
            ground_stations="groundStations",
            hosted_for_company_org_id="hostedForCompanyOrgId",
            id_sensor="idSensor",
            imaging_payload_category="Infrared",
            manufacturer_org_id="manufacturerOrgId",
            name="TOURNESOL",
            notes="Sample Notes",
            number_of_film_return_canisters=1,
            origin="THIRD_PARTY_DATASOURCE",
            pointing_method="Spacecraft",
            recorder_size="1024",
            spectral_band="Green",
            spectral_frequency_limits="0.51",
            swath_width=1.23,
        )
        assert seradataopticalpayload is None

    @parametrize
    def test_raw_response_update(self, client: Unifieddatalibrary) -> None:
        response = client.seradataopticalpayload.with_raw_response.update(
            path_id="id",
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = response.parse()
        assert seradataopticalpayload is None

    @parametrize
    def test_streaming_response_update(self, client: Unifieddatalibrary) -> None:
        with client.seradataopticalpayload.with_streaming_response.update(
            path_id="id",
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = response.parse()
            assert seradataopticalpayload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_update(self, client: Unifieddatalibrary) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_id` but received ''"):
            client.seradataopticalpayload.with_raw_response.update(
                path_id="",
                classification_marking="U",
                data_mode="TEST",
                source="Bluestaq",
                spacecraft_id="spacecraftId",
            )

    @parametrize
    def test_method_list(self, client: Unifieddatalibrary) -> None:
        seradataopticalpayload = client.seradataopticalpayload.list()
        assert_matches_type(SeradataopticalpayloadListResponse, seradataopticalpayload, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Unifieddatalibrary) -> None:
        response = client.seradataopticalpayload.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = response.parse()
        assert_matches_type(SeradataopticalpayloadListResponse, seradataopticalpayload, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Unifieddatalibrary) -> None:
        with client.seradataopticalpayload.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = response.parse()
            assert_matches_type(SeradataopticalpayloadListResponse, seradataopticalpayload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: Unifieddatalibrary) -> None:
        seradataopticalpayload = client.seradataopticalpayload.delete(
            "id",
        )
        assert seradataopticalpayload is None

    @parametrize
    def test_raw_response_delete(self, client: Unifieddatalibrary) -> None:
        response = client.seradataopticalpayload.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = response.parse()
        assert seradataopticalpayload is None

    @parametrize
    def test_streaming_response_delete(self, client: Unifieddatalibrary) -> None:
        with client.seradataopticalpayload.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = response.parse()
            assert seradataopticalpayload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: Unifieddatalibrary) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.seradataopticalpayload.with_raw_response.delete(
                "",
            )

    @parametrize
    def test_method_count(self, client: Unifieddatalibrary) -> None:
        seradataopticalpayload = client.seradataopticalpayload.count()
        assert_matches_type(str, seradataopticalpayload, path=["response"])

    @parametrize
    def test_raw_response_count(self, client: Unifieddatalibrary) -> None:
        response = client.seradataopticalpayload.with_raw_response.count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = response.parse()
        assert_matches_type(str, seradataopticalpayload, path=["response"])

    @parametrize
    def test_streaming_response_count(self, client: Unifieddatalibrary) -> None:
        with client.seradataopticalpayload.with_streaming_response.count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = response.parse()
            assert_matches_type(str, seradataopticalpayload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_get(self, client: Unifieddatalibrary) -> None:
        seradataopticalpayload = client.seradataopticalpayload.get(
            "id",
        )
        assert_matches_type(SeradataopticalpayloadGetResponse, seradataopticalpayload, path=["response"])

    @parametrize
    def test_raw_response_get(self, client: Unifieddatalibrary) -> None:
        response = client.seradataopticalpayload.with_raw_response.get(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = response.parse()
        assert_matches_type(SeradataopticalpayloadGetResponse, seradataopticalpayload, path=["response"])

    @parametrize
    def test_streaming_response_get(self, client: Unifieddatalibrary) -> None:
        with client.seradataopticalpayload.with_streaming_response.get(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = response.parse()
            assert_matches_type(SeradataopticalpayloadGetResponse, seradataopticalpayload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get(self, client: Unifieddatalibrary) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.seradataopticalpayload.with_raw_response.get(
                "",
            )

    @parametrize
    def test_method_queryhelp(self, client: Unifieddatalibrary) -> None:
        seradataopticalpayload = client.seradataopticalpayload.queryhelp()
        assert seradataopticalpayload is None

    @parametrize
    def test_raw_response_queryhelp(self, client: Unifieddatalibrary) -> None:
        response = client.seradataopticalpayload.with_raw_response.queryhelp()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = response.parse()
        assert seradataopticalpayload is None

    @parametrize
    def test_streaming_response_queryhelp(self, client: Unifieddatalibrary) -> None:
        with client.seradataopticalpayload.with_streaming_response.queryhelp() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = response.parse()
            assert seradataopticalpayload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_tuple(self, client: Unifieddatalibrary) -> None:
        seradataopticalpayload = client.seradataopticalpayload.tuple(
            columns="columns",
        )
        assert_matches_type(SeradataopticalpayloadTupleResponse, seradataopticalpayload, path=["response"])

    @parametrize
    def test_raw_response_tuple(self, client: Unifieddatalibrary) -> None:
        response = client.seradataopticalpayload.with_raw_response.tuple(
            columns="columns",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = response.parse()
        assert_matches_type(SeradataopticalpayloadTupleResponse, seradataopticalpayload, path=["response"])

    @parametrize
    def test_streaming_response_tuple(self, client: Unifieddatalibrary) -> None:
        with client.seradataopticalpayload.with_streaming_response.tuple(
            columns="columns",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = response.parse()
            assert_matches_type(SeradataopticalpayloadTupleResponse, seradataopticalpayload, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSeradataopticalpayload:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_create(self, async_client: AsyncUnifieddatalibrary) -> None:
        seradataopticalpayload = await async_client.seradataopticalpayload.create(
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        )
        assert seradataopticalpayload is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncUnifieddatalibrary) -> None:
        seradataopticalpayload = await async_client.seradataopticalpayload.create(
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
            id="SERADATAOPTICALPAYLOAD-ID",
            best_resolution=1.23,
            field_of_regard=1.23,
            field_of_view=1.23,
            ground_station_locations="groundStationLocations",
            ground_stations="groundStations",
            hosted_for_company_org_id="hostedForCompanyOrgId",
            id_sensor="idSensor",
            imaging_payload_category="Infrared",
            manufacturer_org_id="manufacturerOrgId",
            name="TOURNESOL",
            notes="Sample Notes",
            number_of_film_return_canisters=1,
            origin="THIRD_PARTY_DATASOURCE",
            pointing_method="Spacecraft",
            recorder_size="1024",
            spectral_band="Green",
            spectral_frequency_limits="0.51",
            swath_width=1.23,
        )
        assert seradataopticalpayload is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.seradataopticalpayload.with_raw_response.create(
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = await response.parse()
        assert seradataopticalpayload is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.seradataopticalpayload.with_streaming_response.create(
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = await response.parse()
            assert seradataopticalpayload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_update(self, async_client: AsyncUnifieddatalibrary) -> None:
        seradataopticalpayload = await async_client.seradataopticalpayload.update(
            path_id="id",
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        )
        assert seradataopticalpayload is None

    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncUnifieddatalibrary) -> None:
        seradataopticalpayload = await async_client.seradataopticalpayload.update(
            path_id="id",
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
            body_id="SERADATAOPTICALPAYLOAD-ID",
            best_resolution=1.23,
            field_of_regard=1.23,
            field_of_view=1.23,
            ground_station_locations="groundStationLocations",
            ground_stations="groundStations",
            hosted_for_company_org_id="hostedForCompanyOrgId",
            id_sensor="idSensor",
            imaging_payload_category="Infrared",
            manufacturer_org_id="manufacturerOrgId",
            name="TOURNESOL",
            notes="Sample Notes",
            number_of_film_return_canisters=1,
            origin="THIRD_PARTY_DATASOURCE",
            pointing_method="Spacecraft",
            recorder_size="1024",
            spectral_band="Green",
            spectral_frequency_limits="0.51",
            swath_width=1.23,
        )
        assert seradataopticalpayload is None

    @parametrize
    async def test_raw_response_update(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.seradataopticalpayload.with_raw_response.update(
            path_id="id",
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = await response.parse()
        assert seradataopticalpayload is None

    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.seradataopticalpayload.with_streaming_response.update(
            path_id="id",
            classification_marking="U",
            data_mode="TEST",
            source="Bluestaq",
            spacecraft_id="spacecraftId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = await response.parse()
            assert seradataopticalpayload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_update(self, async_client: AsyncUnifieddatalibrary) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_id` but received ''"):
            await async_client.seradataopticalpayload.with_raw_response.update(
                path_id="",
                classification_marking="U",
                data_mode="TEST",
                source="Bluestaq",
                spacecraft_id="spacecraftId",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncUnifieddatalibrary) -> None:
        seradataopticalpayload = await async_client.seradataopticalpayload.list()
        assert_matches_type(SeradataopticalpayloadListResponse, seradataopticalpayload, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.seradataopticalpayload.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = await response.parse()
        assert_matches_type(SeradataopticalpayloadListResponse, seradataopticalpayload, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.seradataopticalpayload.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = await response.parse()
            assert_matches_type(SeradataopticalpayloadListResponse, seradataopticalpayload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncUnifieddatalibrary) -> None:
        seradataopticalpayload = await async_client.seradataopticalpayload.delete(
            "id",
        )
        assert seradataopticalpayload is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.seradataopticalpayload.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = await response.parse()
        assert seradataopticalpayload is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.seradataopticalpayload.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = await response.parse()
            assert seradataopticalpayload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncUnifieddatalibrary) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.seradataopticalpayload.with_raw_response.delete(
                "",
            )

    @parametrize
    async def test_method_count(self, async_client: AsyncUnifieddatalibrary) -> None:
        seradataopticalpayload = await async_client.seradataopticalpayload.count()
        assert_matches_type(str, seradataopticalpayload, path=["response"])

    @parametrize
    async def test_raw_response_count(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.seradataopticalpayload.with_raw_response.count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = await response.parse()
        assert_matches_type(str, seradataopticalpayload, path=["response"])

    @parametrize
    async def test_streaming_response_count(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.seradataopticalpayload.with_streaming_response.count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = await response.parse()
            assert_matches_type(str, seradataopticalpayload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_get(self, async_client: AsyncUnifieddatalibrary) -> None:
        seradataopticalpayload = await async_client.seradataopticalpayload.get(
            "id",
        )
        assert_matches_type(SeradataopticalpayloadGetResponse, seradataopticalpayload, path=["response"])

    @parametrize
    async def test_raw_response_get(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.seradataopticalpayload.with_raw_response.get(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = await response.parse()
        assert_matches_type(SeradataopticalpayloadGetResponse, seradataopticalpayload, path=["response"])

    @parametrize
    async def test_streaming_response_get(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.seradataopticalpayload.with_streaming_response.get(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = await response.parse()
            assert_matches_type(SeradataopticalpayloadGetResponse, seradataopticalpayload, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get(self, async_client: AsyncUnifieddatalibrary) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.seradataopticalpayload.with_raw_response.get(
                "",
            )

    @parametrize
    async def test_method_queryhelp(self, async_client: AsyncUnifieddatalibrary) -> None:
        seradataopticalpayload = await async_client.seradataopticalpayload.queryhelp()
        assert seradataopticalpayload is None

    @parametrize
    async def test_raw_response_queryhelp(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.seradataopticalpayload.with_raw_response.queryhelp()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = await response.parse()
        assert seradataopticalpayload is None

    @parametrize
    async def test_streaming_response_queryhelp(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.seradataopticalpayload.with_streaming_response.queryhelp() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = await response.parse()
            assert seradataopticalpayload is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_tuple(self, async_client: AsyncUnifieddatalibrary) -> None:
        seradataopticalpayload = await async_client.seradataopticalpayload.tuple(
            columns="columns",
        )
        assert_matches_type(SeradataopticalpayloadTupleResponse, seradataopticalpayload, path=["response"])

    @parametrize
    async def test_raw_response_tuple(self, async_client: AsyncUnifieddatalibrary) -> None:
        response = await async_client.seradataopticalpayload.with_raw_response.tuple(
            columns="columns",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        seradataopticalpayload = await response.parse()
        assert_matches_type(SeradataopticalpayloadTupleResponse, seradataopticalpayload, path=["response"])

    @parametrize
    async def test_streaming_response_tuple(self, async_client: AsyncUnifieddatalibrary) -> None:
        async with async_client.seradataopticalpayload.with_streaming_response.tuple(
            columns="columns",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            seradataopticalpayload = await response.parse()
            assert_matches_type(SeradataopticalpayloadTupleResponse, seradataopticalpayload, path=["response"])

        assert cast(Any, response.is_closed) is True
